==> eam-wshub-proxyclient-11.4-14-sources.jar: net/datastream/schemas/mp_fields/NONCONFORMITYOBSERVATIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour NONCONFORMITYOBSERVATIONID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="NONCONFORMITYOBSERVATIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OBSERVATIONPK"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NONCONFORMITYCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OBSERVATIONNUM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "NONCONFORMITYOBSERVATIONID_Type", propOrder = {
    "observationpk",
    "nonconformitycode",
    "observationnum",
    "organizationid",
    "description"
})
public class NONCONFORMITYOBSERVATIONID_Type {

    @XmlElement(name = "OBSERVATIONPK", required = true)
    protected String observationpk;
    @XmlElement(name = "NONCONFORMITYCODE")
    protected String nonconformitycode;
    @XmlElement(name = "OBSERVATIONNUM")
    protected QUANTITY observationnum;
    @XmlElement(name = "ORGANIZATIONID")
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Obtient la valeur de la propriété observationpk.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOBSERVATIONPK() {
        return observationpk;
    }

    /**
     * Définit la valeur de la propriété observationpk.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOBSERVATIONPK(String value) {
        this.observationpk = value;
    }

    /**
     * Obtient la valeur de la propriété nonconformitycode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNONCONFORMITYCODE() {
        return nonconformitycode;
    }

    /**
     * Définit la valeur de la propriété nonconformitycode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNONCONFORMITYCODE(String value) {
        this.nonconformitycode = value;
    }

    /**
     * Obtient la valeur de la propriété observationnum.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getOBSERVATIONNUM() {
        return observationnum;
    }

    /**
     * Définit la valeur de la propriété observationnum.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setOBSERVATIONNUM(QUANTITY value) {
        this.observationnum = value;
    }

    /**
     * Obtient la valeur de la propriété organizationid.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Définit la valeur de la propriété organizationid.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Obtient la valeur de la propriété description.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Définit la valeur de la propriété description.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/NONCONFORMITYOBSERVATIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for NONCONFORMITYOBSERVATIONID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="NONCONFORMITYOBSERVATIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OBSERVATIONPK"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}NONCONFORMITYCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OBSERVATIONNUM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORGANIZATIONID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DESCRIPTION" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "NONCONFORMITYOBSERVATIONID_Type", propOrder = {
    "observationpk",
    "nonconformitycode",
    "observationnum",
    "organizationid",
    "description"
})
public class NONCONFORMITYOBSERVATIONID_Type {

    @XmlElement(name = "OBSERVATIONPK", required = true)
    protected String observationpk;
    @XmlElement(name = "NONCONFORMITYCODE")
    protected String nonconformitycode;
    @XmlElement(name = "OBSERVATIONNUM")
    protected QUANTITY observationnum;
    @XmlElement(name = "ORGANIZATIONID")
    protected ORGANIZATIONID_Type organizationid;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the observationpk property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOBSERVATIONPK() {
        return observationpk;
    }

    /**
     * Sets the value of the observationpk property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOBSERVATIONPK(String value) {
        this.observationpk = value;
    }

    /**
     * Gets the value of the nonconformitycode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNONCONFORMITYCODE() {
        return nonconformitycode;
    }

    /**
     * Sets the value of the nonconformitycode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNONCONFORMITYCODE(String value) {
        this.nonconformitycode = value;
    }

    /**
     * Gets the value of the observationnum property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getOBSERVATIONNUM() {
        return observationnum;
    }

    /**
     * Sets the value of the observationnum property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setOBSERVATIONNUM(QUANTITY value) {
        this.observationnum = value;
    }

    /**
     * Gets the value of the organizationid property.
     * 
     * @return
     *     possible object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public ORGANIZATIONID_Type getORGANIZATIONID() {
        return organizationid;
    }

    /**
     * Sets the value of the organizationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ORGANIZATIONID_Type }
     *     
     */
    public void setORGANIZATIONID(ORGANIZATIONID_Type value) {
        this.organizationid = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}
